# tests

This directory contains quick tests of methods that we rely on heavily throughout this project. You can simply run the tests in the same manner.

In the future, we intend to use error code to differentiate between successful and failed tests.
